@@ -80,7 +80,7 @@ class NerBIO:
         }
 
     @staticmethod
-    def deal_with_df(df):
+    def deal_with_df(df: pd.DataFrame):
         df = df[["sentence_id", "words", "labels"]]
         df = df.astype({'sentence_id': 'int', 'words': 'str', 'labels': 'str'})
         return df
@@ -92,6 +92,7 @@ class NerBIO:
         train_size = len(set(train_data['sentence_id'].tolist()))
         eval_size = len(set(eval_data['sentence_id'].tolist()))
 
+        # update args
         all_steps = train_size / self.model_args.get('train_batch_size')
         self.model_args.update(
             {
@@ -129,13 +130,13 @@ class NerBIO:
     @staticmethod
     def _get_id_entity(pred_list, label='DISEASE'):
         """
-        从一个bio格式的序列中获得id实体，比如：['O', 'O', 'O', 'B-DISEASE', 'I-DISEASE', 'O', ]---->['-3-4-5']
+        从一个bio格式的序列中获得id实体，比如：['O', 'O', 'O', 'B-DISEASE', 'I-DISEASE', 'O', ]---->['-3-4']
         Args:
             pred_list: ['O', 'O', 'O', 'B-DISEASE', 'I-DISEASE', 'O', ]
             label: DISEASE
 
         Returns:
-                ['-3-4-5']
+                ['-3-4']
         """
         if not label:
             label = ''
@@ -143,7 +144,7 @@ class NerBIO:
         e = ''
         is_entity = 0
         for index, p in enumerate(pred_list):
-            if p == '0':
+            if p == 'O':
                 if is_entity == 1:
                     entities.append(e)
                 is_entity = 0
@@ -159,7 +160,7 @@ class NerBIO:
             entities.append(e)
         return entities
 
-    def eval(self, eval_df: pd.DataFrame, use_t5_matric=False):
+    def eval(self, eval_df: pd.DataFrame, use_t5_metric=False):
         eval_data = NerBIO.deal_with_df(eval_df)
         eval_size = len(set(eval_df['sentence_id'].tolist()))
 
@@ -179,7 +180,7 @@ class NerBIO:
 
         result, model_outputs, preds_list = model.eval_model(eval_data)
 
-        if use_t5_matric:
+        if use_t5_metric:
             labels = eval_data.groupby(by=['sentence_id'], sort=False)
             labels = labels.apply(lambda x: x['labels'].tolist())
 
@@ -187,10 +188,16 @@ class NerBIO:
             labels = [set(NerBIO._get_id_entity(l)) for l in labels]
             from zyl_utils.model_utils.metrics.ner_metric import entity_recognition_v2
             res_df = entity_recognition_v2(labels, preds_list)
+            wandb.log({"t5_res": res_df.iloc[2,-1]})
+
+        wandb.log({"f1_score": result.get('f1_score')})
+
+    @staticmethod
+    def predict(model, to_predict):
+        pass
 
 
 if __name__ == '__main__':
-
     class Trainer(NerBIO):
         def __init__(self):
             super(Trainer, self).__init__()
@@ -226,6 +233,7 @@ if __name__ == '__main__':
             self.labels = ["O", "B-DISEASE", "I-DISEASE"]
             self.train(train_df, eval_df)
 
+
     class Evaluator(NerBIO):
         def __init__(self):
             super(Evaluator, self).__init__()
@@ -235,7 +243,7 @@ if __name__ == '__main__':
             eval_file = './test.xlsx'
             eval_data = pd.read_excel(eval_file)
 
-            self.save_dir = '../'
+            self.save_dir = './'
             self.model_version = 'erv4.2.0.2'
             self.model_type = 'bert'
             self.use_cuda = True
@@ -251,15 +259,6 @@ if __name__ == '__main__':
             )
             self.eval(eval_data)
 
-        print('1')
-        # # wandb updata
-        # wandb.init(
-        #     project=self.wandb_proj,
-        #     config = self.model_args,
-        #     name=self.model_version + time.strftime("_%m%d_%H:%M:%S", time.localtime()),
-        #     tags=[self.model_version, 'eval']
-        # )
-        # wandb.log({"f1_score": result.get('f1_score')})
-
-
 
+    print(NerBIO._get_id_entity(['B-DISEASE', 'I-DISEASE','O','O','B-DISEASE',
+                                 'B-DISEASE', 'I-DISEASE', 'B-DISEASE',]))
\ No newline at end of file
