@@ -20,7 +20,7 @@ class MyT5(T5Model):
     """
 
     def __init__(self, model_type, model_name, args=None, tokenizer=None, use_cuda=True, cuda_device=-1, **kwargs):
-        super(MyT5, self).__init__(self, model_type=model_type, model_name=model_name, args=args,
+        super(MyT5, self).__init__(model_type=model_type, model_name=model_name, args=args,
                                    tokenizer=tokenizer, use_cuda=use_cuda, cuda_device=cuda_device, **kwargs)
 
     def get_funcs(self, gpus):
@@ -69,7 +69,7 @@ class MyDDPT5(DDPT5Model):
     """
 
     def __init__(self, model_type, model_name, args=None, tokenizer=None, use_cuda=True, cuda_device=-1, **kwargs):
-        super(MyDDPT5, self).__init__(self, model_type=model_type, model_name=model_name, args=args,
+        super(MyDDPT5, self).__init__(model_type=model_type, model_name=model_name, args=args,
                                       tokenizer=tokenizer, use_cuda=use_cuda, cuda_device=cuda_device, **kwargs)
 
     def get_funcs(self, gpus):
