@@ -45,7 +45,7 @@ class NERUtils:
             tokenizer: tokenizer to split sentence
 
         Returns:
-            show report and res
+            show report and res, {prefix:res_df},type:dict
         """
 
         prefixes = eval_df['prefix'].to_list()
@@ -386,8 +386,17 @@ class NERUtils:
 
         sum_metric_weighted = pos_ratio * pos_metric + neg_ratio * neg_metric
 
-        # precision = pos_correct_dt / (neg_correct_dt + pos_correct_dt)
+        # pos_precision = pos_correct_dt / (neg_correct_dt + pos_correct_dt)
         # recall = pos_correct_dt / pos_data
+        tp = pos_correct_dt
+        fn = pos_wrong_dt
+        fp = neg_wrong_dt
+        tn = neg_correct_dt
+
+        accuracy = (tp + tn) / (tp + fn + fp + tn)
+        # precision = tp / (tp + fp)
+        # recall = tp / (tp + fn)
+        # f1 = 2 / (1 / precision + 1 / recall)
         r = {
             'positive data': [str(pos_data), pos_correct_dt, pos_wrong_dt, pos_correct_entities,
                               pos_wrong_entities, pos_omitted_entities, pos_redundant_entities, pos_metric],
@@ -423,7 +432,9 @@ class NERUtils:
             f"{pos_redundant_entities}) = {round(pos_metric, 4)}，负样本集得分为：{neg_correct_dt} / ({neg_correct_dt} + "
             f"{neg_redundant_entities})={round(neg_metric, 4)}，",
             f"总体得分为： ({pos_correct_entities} + {neg_correct_dt}) / "
-            f"({all_pos_entities}+{neg_correct_dt + neg_redundant_entities})={round(sum_metric_micro, 4)}")
+            f"({all_pos_entities}+{neg_correct_dt + neg_redundant_entities})={round(sum_metric_micro, 4)}",
+            f"准确率：{accuracy}",
+        )
         print('\n')
         if self_metric:
             more_not_error_pos = (pos_correct_entities + pos_redundant_entities) / (
